Master:
  .. image:: https://travis-ci.org/unfoldingWord-dev/python-aws-tools.svg?branch=master
    :alt: Build Status
    :target: https://travis-ci.org/unfoldingWord-dev/python-aws-tools
  .. image:: https://coveralls.io/repos/github/unfoldingWord-dev/python-gogs-client/badge.svg?branch=master
    :alt: Coverage
    :target: https://coveralls.io/github/unfoldingWord-dev/python-aws-tools?branch=master

Develop:
  .. image:: https://travis-ci.org/unfoldingWord-dev/python-aws-tools.svg?branch=develop
    :alt: Build Status
    :target: https://travis-ci.org/unfoldingWord-dev/python-aws-tools
  .. image:: https://coveralls.io/repos/github/unfoldingWord-dev/python-aws-tools/badge.svg?branch=develop
    :alt: Coverage
    :target: https://coveralls.io/github/unfoldingWord-dev/python-aws-tools?branch=develop

python-aws-tools
================
A library for performing actions against the AWS api

Deploy via the command line:

    $ python setup.py sdist bdist_wheel
    $ twine upload dist/*

Or tag a new release on the repo and let travis do the work.